@@ -1230,16 +1230,14 @@ class InternetArchiveItem(models.Model):
                             )
                         )
 
-                        # this is just a logging function so we can see
-                        # what's going on
-                        if sample_count == 1000:
-                            progress.console.print(
-                                f"{url}, {outcome.ext_ids.doi}, {outcome.ident}"
-                            )
-                            sample_count = 0
-
                         count += 1
 
+                    # this is just a logging function so we can see
+                    # what's going on
+                    if sample_count == 100000:
+                        progress.console.print(f"{data}")
+                        sample_count = 0
+
                     sample_count += 1
 
                     if count == 1000:
